@@ -16,7 +16,7 @@ try:
 except InvalidCacheBackendError:
     raise SkipTest("an appropriate mmongodb backend is not installed")
 
-uri = 'mongodb://localhost/test.beaker'
+uri = 'mongodb://localhost/test.beaker?replicaSet=test'
 
 _mongo = Connection('localhost').test
 
